<template>
    <el-dialog
        :visible.sync="personPurchaseDetailVisible"
        :close-on-click-modal="false"
        width="70%"
        :append-to-body="true"
    >
        <div class="app-container">
        <div class="filter-container">
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px">
                    <span>单号：</span>
                    <el-input filterable clearable v-model="code" style="width:200px" readonly>
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>入库日期：</span>
                    <el-input filterable clearable v-model="entryDate" style="width:200px" readonly>
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>运输证号：</span>
                    <el-input filterable clearable v-model="transportCert" style="width:200px" readonly>
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>产品数量：</span>
                    <el-input filterable clearable v-model="num" style="width:200px" readonly>
                    </el-input>
                </div>
            </div>

        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="personPurchaseDetailData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="产品名称" prop="productname" align="center">
                </el-table-column>
                <el-table-column label="产品包装码" prop="directioncode" align="center">
                    <template slot-scope="scope">
                        <span style="color: blue" @click="showFlow(scope.row.directioncode)">{{scope.row.directioncode}}</span>
                    </template>
                </el-table-column>
                <el-table-column label="类型" prop="type" align="center">
                </el-table-column>
                <el-table-column label="规格" prop="specification" align="center">
                </el-table-column>
                <el-table-column label="含药量" prop="explosivecontent" align="center">
                </el-table-column>
                <el-table-column label="箱含量" prop="boxnumber" align="center">
                </el-table-column>
                <el-table-column label="入库数量" prop="num" align="center">
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
            <flow ref="flow"></flow>
        </div>
    </el-dialog>
</template>

<script>
    import flow from './flow'
import {getInStorageDetailListData} from "../../../api/flow";
import {computePageCount} from "../../../utils";

export default {
    name: "index",
    data(){
        return{
            code:'',
            entryDate:'',
            num:'',
            tableKey:'',
            transportCert:'',
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            personPurchaseDetailData:[],
            personPurchaseDetailVisible:false,
            listQuery: {
                pageSize:10,
                pageIndex:1,
                filter: {
                    code:''
                },
            },
        }
    },
    components: {
        flow
    },
    methods:{
        openInStorageDetail(val){
            this.personPurchaseDetailVisible = true
            this.listQuery.filter.code = val.code
            this.listQuery.pageIndex = 1
            this.code = val.code
            this.transportCert = val.transportcert
            this.entryDate = val.entrydate
            this.num = val.num
            this.getInStorageDetailList()
        },
        showFlow(val){
            this.$refs.flow.openFlow(val)
        },
        async getInStorageDetailList(){
            this.listLoading = true
            let res = await getInStorageDetailListData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.personPurchaseDetailData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getInStorageDetailList()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getInStorageDetailList()
        },
    }
}
</script>

<style scoped>
.basic_search{
    display:inline-block;
}
</style>
